@@ -51,15 +51,15 @@ class account():
         self.controller = controller
         #these store all the data associated with this accounts tweets
         # the fields are : Name,sender_id,Tweet,TweetColour,id, type, timestamp, replyTo, source, pic, formatted_tweet
-        self.tweetstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT , str, str, gtk.gdk.Pixbuf, str)
+        self.tweetstore = gtk.ListStore(str, str, str, str, float, str, str , str, str, gtk.gdk.Pixbuf, str)
         #then we want the same again to store dm's, mentions & pubilc timeline separately
-        self.dmstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
-        self.mentionstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
-        self.publicstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
-        self.trendstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
-        self.friendsstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
-        self.searchstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
-        self.userhistorystore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
+        self.dmstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
+        self.mentionstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
+        self.publicstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
+        self.trendstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
+        self.friendsstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
+        self.searchstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
+        self.userhistorystore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
         #store of avatar, filename, access count
         self.avatars = gtk.ListStore(gtk.gdk.Pixbuf, str, int, str)
         #base url can be set to any twitter compatible site, so we can support mutliple account types
@@ -216,8 +216,9 @@ class account():
                  created_at = self.parse_time(x.created_at)
                  formatted_ts = self.format_timestamp(created_at)
                  formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
+                 longid= long(x.id)
+                 self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  
-                 self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
@@ -299,7 +300,7 @@ class account():
                  created_at = self.parse_time(x.created_at)
                  formatted_ts = self.format_timestamp(created_at)
                  formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
-                 self.mentionstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                 self.mentionstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
@@ -372,7 +373,7 @@ class account():
                  created_at = self.parse_time(x.created_at)
                  formatted_ts = self.format_timestamp(created_at)
                  formatted_tweet = self.format_tweet(user, text, formatted_ts, None, None)
-                 self.dmstore.append([ "@" + user, x.GetSenderId(), "@" + user + " : " + text, "", x.id, "Tweet", x.created_at, "", "", pic, formatted_tweet])
+                 self.dmstore.append([ "@" + user, x.GetSenderId(), "@" + user + " : " + text, "", long(x.id), "Tweet", x.created_at, "", "", pic, formatted_tweet])
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
@@ -427,7 +428,7 @@ class account():
                     created_at = self.parse_time(tweettime)
                     formatted_ts = self.format_timestamp(created_at)
                     formatted_tweet = self.format_tweet(x.screen_name, status, formatted_ts, source, None)
-                    self.friendsstore.append([ "@" + x.screen_name, str(x.id), "@" + x.screen_name + " : " + status, "", x.id, "friend", tweettime, "", source, pic, formatted_tweet])
+                    self.friendsstore.append([ "@" + x.screen_name, str(x.id), "@" + x.screen_name + " : " + status, "", long(x.id), "friend", tweettime, "", source, pic, formatted_tweet])
                     receive_count = receive_count + 1
 
                 if (receive_count > 0):
@@ -508,7 +509,7 @@ class account():
                  created_at = self.parse_time(x.created_at)
                  formatted_ts = self.format_timestamp(created_at)
                  formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
-                 self.publicstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                 self.publicstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
@@ -565,7 +566,7 @@ class account():
                  created_at = self.parse_time(x.created_at)
                  formatted_ts = self.format_timestamp(created_at)
                  formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
-                 self.userhistorystore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                 self.userhistorystore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
@@ -636,7 +637,7 @@ class account():
                     created_at = self.parse_time(x['created_at'])
                     formatted_ts = self.format_timestamp(created_at)
                     formatted_tweet = self.format_tweet(x['from_user'], text, formatted_ts, source, reply_to)
-                    self.searchstore.append([ "@" + x['from_user'], str(x['from_user_id']), "@" + x['from_user'] + " : " + text, "", x['id'], "Search", x['created_at'], reply_to, source, pic, formatted_tweet])
+                    self.searchstore.append([ "@" + x['from_user'], str(x['from_user_id']), "@" + x['from_user'] + " : " + text, "", long(x['id']), "Search", x['created_at'], reply_to, source, pic, formatted_tweet])
                     receive_count = receive_count + 1
                     note = osso.SystemNote(self.osso_c)
                     result = note.system_note_infoprint("Search results Received for : " + term)
@@ -848,7 +849,7 @@ class account():
                         self.update_all_avatars(id, pixbuf)
                     return pixbuf
                 else:
-                    print "re-using file already loaded"
+                    
                     self.avatars.set_value(item, 2, (self.avatars.get_value(item, 2) + 1))
                     return self.avatars.get_value(item, 0)
             item = self.avatars.iter_next(item)
@@ -857,7 +858,7 @@ class account():
             pixbuf = gtk.gdk.pixbuf_new_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)
             pixbuf = pixbuf.scale_simple(self.avatar_size, self.avatar_size, gtk.gdk.INTERP_BILINEAR)
             self.avatars.append([pixbuf, filename, 1, name])
-            print "loaded pixbuf from file"
+            
             return pixbuf
         else:
             try:
@@ -884,7 +885,7 @@ class account():
                 os.mkdir("/home/user/.witterPics/" + self.accountdata.servicename)
 
             webFile = urllib.urlopen(url)
-            print "fetched image"
+            
             localFile = open("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename, 'w')
             localFile.write(webFile.read())
             webFile.close()
@@ -969,18 +970,22 @@ class account():
     def parse_time(self, timestr):
         #parses a time string from twitter into a date object
         #timestr = "Wed Apr 07 09:45:28 +0000 2010"
-        if (timestr.find("+") == -1):
-            #negative offset from UTC
-            strippedDate = timestr[0: timestr.find("-")] + "+0000" + timestr[timestr.find("-") + 5: len(timestr)]
-            hoursOffset = int(timestr[timestr.find("-") + 1:timestr.find("-") + 3])
-            print "offset hours = -" + str(hoursOffset)
-            minus = True
-        else:
-            #positive offset from UTC
-            strippedDate = timestr[0: timestr.find("+")] + "+0000" + timestr[timestr.find("+") + 5: len(timestr)]
-            hoursOffset = int(timestr[timestr.find("+") + 1:timestr.find("+") + 3])
-            print "offset hours = +" + str(hoursOffset)
-            minus = False
+        try:
+            if (timestr.find("+") == -1):
+                #negative offset from UTC
+                strippedDate = timestr[0: timestr.find("-")] + "+0000" + timestr[timestr.find("-") + 5: len(timestr)]
+                hoursOffset = int(timestr[timestr.find("-") + 1:timestr.find("-") + 3])
+                print "offset hours = -" + str(hoursOffset)
+                minus = True
+            else:
+                #positive offset from UTC
+                strippedDate = timestr[0: timestr.find("+")] + "+0000" + timestr[timestr.find("+") + 5: len(timestr)]
+                hoursOffset = int(timestr[timestr.find("+") + 1:timestr.find("+") + 3])
+                print "offset hours = +" + str(hoursOffset)
+                minus = False
+        except ValueError:
+            print "error parsing timestamp: " +timestr
+            return datetime.datetime.today()   
         try:
 
 
